#!/usr/bin/perl
#
# update20.pl is a small perl script to update QtArch dlg files from version
# 1.xx up to version 2.xx
#
# It simply reads in all files from the argument list and changes 
# - Signals and slots from using const char to the new QString &
# - Palette settings from Qt 1.x to Qt 2.x
#
# Any comments, critics, etc. to klaus@gaspode.ndh.com
#
# Part of the qtarch 2.x distribution
# Author: klaus ebner
# Licence: GPL
# Version: 1.0
# Date: 28.09.99

while( @ARGV )
  {
    $newName = shift ARGV;
    $oldName = "$newName.portBackup";
    rename $newName, $oldName;
    open( INFILE, $oldName ) || die "can't find $oldName";
    open( OUTFILE, ">$newName" );
    
  READLOOP:
    while( <INFILE> )
      {
        # Check for version number and report
        if( /^(DlgEdit:v)([\d\.]*)(:Dialog:)/ )
	  {
	    if( $2 eq "2.0" ) 
	      {
		close INFILE;
		close OUTFILE;
		rename $oldName, $newName;
		print "$newName already converted\n";
		last READLOOP;
	      }
	    else
	      {
		print OUTFILE $1, "2.0", $3, "\n";
		next READLOOP;
	      }  
	  }  
	
	
        # Change signals and slots from const char* to const QString &
	s/(^\s*Signal\s*\{\[\w*\]\s*(textChanged|activated|highlighted|selected|valueChanged)\s*-->\s*\w*\s*)\(const char\*\)\}/$1(const QString&)/g;
	
        # Update palette from Qt 1.x to Qt 2.x
	if( /^(\s*)Palette\s*\{([\d\s]*)\}/ )
	  {
	    @rgbs = split( /\s/, $2 );
	    undef @newRgbs;
	    while( @rgbs )
	      {
		$oldRgb = shift( @rgbs );
                
                # swapping red and blue
                $newRgb = ($oldRgb & 0xFF) << 16;
                $newRgb |= ($oldRgb & 0xFF00);
                $newRgb |= ($oldRgb & 0xFF0000) >> 16;
                push( @newRgbs, $newRgb );
	      }
	    
            # Reorder from fore back   light dark mid text base
            #         to   fore button light dark mid text base back midlight 
            #              brightText buttonText shadow highlight highlightedText
            # by setting unknown values to 0
            $outRgbs[0] = $newRgbs[0];
            $outRgbs[1] = 0;
            $outRgbs[2] = $newRgbs[2];
            $outRgbs[3] = $newRgbs[3];
            $outRgbs[4] = $newRgbs[4];
            $outRgbs[5] = $newRgbs[5];
            $outRgbs[6] = $newRgbs[6];
            $outRgbs[7] = $newRgbs[1];
            $outRgbs[8] = 0;
            $outRgbs[9] = 0;
            $outRgbs[10] = 0;
            $outRgbs[11] = 0;
            $outRgbs[12] = 0;
            $outRgbs[13] = 0;
	    
	    print OUTFILE "$1Palette {", join( ' ', @outRgbs ), "}\n";
	  } 
	else
	  {
	    print OUTFILE;
	  }
      }
    close( INFILE );
    close( OUTFILE );
  }

